@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: resource-pool
 version: 0.2.3.2
-id: resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
-key: resou_GAULhEcayheCJoctyzJJfg
+id: resource-pool-0.2.3.2-1d704fbdc1706c3584f9663671e9b735
+key: resou_GCKRgWBJPdN4Nax9bkIYcU
 license: BSD3
 copyright: Copyright 2011 MailRank, Inc.
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/resource-pool-0.2.3.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/resource-pool-0.2.3.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/resource-pool-0.2.3.2
-hs-libraries: HSresource-pool-0.2.3.2-GAULhEcayheCJoctyzJJfg
+hs-libraries: HSresource-pool-0.2.3.2-GCKRgWBJPdN4Nax9bkIYcU
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
